inline Priority SyslogStream::setDefaultPriority(Priority priority)
{
    return SyslogBuf::setDefaultPriority(priority);
}        
